package com.ruoyi.base.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.base.mapper.RobotOpsWhitelistMapper;
import com.ruoyi.base.domain.RobotOpsWhitelist;
import com.ruoyi.base.service.IRobotOpsWhitelistService;

/**
 * 访客白名单Service业务层处理
 *
 * @author ruoyi
 * @date 2026-04-29
 */
@Service
public class RobotOpsWhitelistServiceImpl implements IRobotOpsWhitelistService
{
    @Autowired
    private RobotOpsWhitelistMapper robotOpsWhitelistMapper;

    /**
     * 查询访客白名单
     *
     * @param id 访客白名单主键
     * @return 访客白名单
     */
    @Override
    public RobotOpsWhitelist selectRobotOpsWhitelistById(Long id)
    {
        return robotOpsWhitelistMapper.selectRobotOpsWhitelistById(id);
    }

    /**
     * 查询访客白名单列表
     *
     * @param robotOpsWhitelist 访客白名单
     * @return 访客白名单
     */
    @Override
    public List<RobotOpsWhitelist> selectRobotOpsWhitelistList(RobotOpsWhitelist robotOpsWhitelist)
    {
        return robotOpsWhitelistMapper.selectRobotOpsWhitelistList(robotOpsWhitelist);
    }

    /**
     * 新增访客白名单
     *
     * @param robotOpsWhitelist 访客白名单
     * @return 结果
     */
    @Override
    public int insertRobotOpsWhitelist(RobotOpsWhitelist robotOpsWhitelist)
    {
        robotOpsWhitelist.setCreateTime(DateUtils.getNowDate());
        return robotOpsWhitelistMapper.insertRobotOpsWhitelist(robotOpsWhitelist);
    }

    /**
     * 修改访客白名单
     *
     * @param robotOpsWhitelist 访客白名单
     * @return 结果
     */
    @Override
    public int updateRobotOpsWhitelist(RobotOpsWhitelist robotOpsWhitelist)
    {
        robotOpsWhitelist.setUpdateTime(DateUtils.getNowDate());
        return robotOpsWhitelistMapper.updateRobotOpsWhitelist(robotOpsWhitelist);
    }

    /**
     * 批量删除访客白名单
     *
     * @param ids 需要删除的访客白名单主键
     * @return 结果
     */
    @Override
    public int deleteRobotOpsWhitelistByIds(Long[] ids)
    {
        return robotOpsWhitelistMapper.deleteRobotOpsWhitelistByIds(ids);
    }

    /**
     * 删除访客白名单信息
     *
     * @param id 访客白名单主键
     * @return 结果
     */
    @Override
    public int deleteRobotOpsWhitelistById(Long id)
    {
        return robotOpsWhitelistMapper.deleteRobotOpsWhitelistById(id);
    }
}
